@@ -7,11 +7,12 @@ for details about the measurement see:
     http://dx.doi.org/10.1088/0957-4484/22/42/425704
 """
 
-import numpy
-import matplotlib.pyplot as plt
-import xrayutilities as xu
 import os
 
+import matplotlib.pyplot as plt
+import numpy
+import xrayutilities as xu
+
 # global setting for the experiment
 sample = "test"  # sample name used also as file name for the data file
 energy = 8042.5  # x-ray energy in eV
@@ -22,12 +23,11 @@ nchannel = 1500  # number of channels of the detector
 
 # intensity normalizer function responsible for count time and absorber
 # correction
-absfun = lambda d: d["detcorr"] / d["psd2"].astype(numpy.float)
 normalizer_detcorr = xu.IntensityNormalizer(
     "MCA",
     mon="Monitor",
     time="Seconds",
-    absfun=absfun)
+    absfun=lambda d: d["detcorr"] / d["psd2"].astype(numpy.float))
 
 # substrate material used for Bragg peak calculation to correct for
 # experimental offsets
@@ -86,7 +86,7 @@ INT = xu.maplog(gridder.data.T, 8., 0)
 # plot the intensity as contour plot using matplotlib
 plt.figure()
 cf = plt.contourf(gridder.xaxis, gridder.yaxis, INT, 100, extend='min')
-plt.xlabel(r'$Q_{[11\bar2]}$ ($\AA^{-1}$)')
-plt.ylabel(r'$Q_{[\bar1\bar1\bar1]}$ ($\AA^{-1}$)')
+plt.xlabel(r'$Q_{[11\bar2]}$ ($\mathrm{\AA}^{-1}$)')
+plt.ylabel(r'$Q_{[\bar1\bar1\bar1]}$ ($\mathrm{\AA}^{-1}$)')
 cb = plt.colorbar(cf)
 cb.set_label(r"$\log($Int$)$ (cps)")
